Print

Print


Author: [log in to unmask]
Date: Thu Oct 30 13:17:22 2014
New Revision: 1352

Log:
Implement the abstract method used to retrieve the t0 shifts from the conditions set.  Remove all setters in favor of the generic setters in the base class. 

Modified:
    java/branches/hps_java_trunk_HPSJAVA-255/conditions/src/main/java/org/hps/conditions/svt/SvtConditions.java
    java/branches/hps_java_trunk_HPSJAVA-255/conditions/src/main/java/org/hps/conditions/svt/TestRunSvtConditions.java

Modified: java/branches/hps_java_trunk_HPSJAVA-255/conditions/src/main/java/org/hps/conditions/svt/SvtConditions.java
 =============================================================================
--- java/branches/hps_java_trunk_HPSJAVA-255/conditions/src/main/java/org/hps/conditions/svt/SvtConditions.java	(original)
+++ java/branches/hps_java_trunk_HPSJAVA-255/conditions/src/main/java/org/hps/conditions/svt/SvtConditions.java	Thu Oct 30 13:17:22 2014
@@ -3,25 +3,23 @@
 import org.hps.conditions.svt.SvtChannel.SvtChannelCollection;
 import org.hps.conditions.svt.SvtDaqMapping.SvtDaqMappingCollection;
 
+import org.hps.conditions.svt.SvtT0Shift.SvtT0ShiftCollection;
+
 // TODO: Move all constants to their own class
 import static org.hps.conditions.svt.SvtChannel.MAX_NUMBER_OF_SAMPLES;
 
 /**
- * This class contains all SVT conditions data by readout channel. {@link SvtChannel}
- * objects from the {@linkSvtChannelMap} should be used to lookup the conditions using the
- * {@link #getChannelConstants(SvtChannel)} method.
+ * 
+ * This class contains all test run SVT conditions data by readout channel. 
+ * {@link SvtChannel} objects from the SVT channel map should be used to
+ * lookup the conditions using the {@link #getChannelConstants(SvtChannel)}
+ * method.
  * 
  * @author Jeremy McCormick <[log in to unmask]>
  * @author Omar Moreno <[log in to unmask]>
  */
 public final class SvtConditions extends AbstractSvtConditions {
 
-    /** SVT conditions data. */
-    protected SvtDaqMappingCollection daqMap = null;
-    
-    public SvtConditions(){
-    }
-    
 	/**
      * Get the {@link SvtDaqMappingCollection} associated with these conditions.
      * 
@@ -29,7 +27,7 @@
      */
     @Override
     public SvtDaqMappingCollection getDaqMap(){
-        return daqMap;
+        return (SvtDaqMappingCollection) daqMap;
     }
 
     /**
@@ -42,25 +40,16 @@
         return (SvtChannelCollection) channelMap;
     }
     
 	/**
      * Set the {@link SvtDaqMappingCollection} associated with these conditions.
      * 
-     * @param daqMap The SVT DAQ map.
-	 * @return 
+     * @return The {@link SvtT0ShiftCollection}
      */
-    public void setDaqMap(SvtDaqMappingCollection daqMap) {
-        this.daqMap = daqMap;
+    @Override
+    public SvtT0ShiftCollection getT0Shifts() { 
+    	return (SvtT0ShiftCollection) t0Shifts;
     }
-   
     
-    /**
-     * Set the channel map of type {@link SvtChannelCollection}.
-     * 
-     *  @param channelMap The SVT channel map.
-     */
-    public void setChannelMap(SvtChannelCollection channelMap){
-    	this.channelMap = channelMap;
-    }
 
     /**
      * Convert this object to a human readable string. This method prints a formatted
@@ -42,25 +40,16 @@
     }
     
-	/**
-     * Set the {@link SvtDaqMappingCollection} associated with these conditions.
+    /**
+     * Get the {@link SvtT0ShiftCollection} associated with these conditions.
      * 

Modified: java/branches/hps_java_trunk_HPSJAVA-255/conditions/src/main/java/org/hps/conditions/svt/TestRunSvtConditions.java
 =============================================================================
--- java/branches/hps_java_trunk_HPSJAVA-255/conditions/src/main/java/org/hps/conditions/svt/TestRunSvtConditions.java	(original)
+++ java/branches/hps_java_trunk_HPSJAVA-255/conditions/src/main/java/org/hps/conditions/svt/TestRunSvtConditions.java	Thu Oct 30 13:17:22 2014
@@ -3,21 +3,22 @@
 import org.hps.conditions.svt.TestRunSvtChannel.TestRunSvtChannelCollection;
 import org.hps.conditions.svt.TestRunSvtDaqMapping.TestRunSvtDaqMappingCollection;
 
+import org.hps.conditions.svt.TestRunSvtT0Shift.TestRunSvtT0ShiftCollection;
+
 // TODO: Move all constants to their own class
 import static org.hps.conditions.svt.SvtChannel.MAX_NUMBER_OF_SAMPLES;
 
 /**
- * This class contains all test run SVT conditions data by readout channel. {@link SvtChannel}
- * objects from the {@linkSvtChannelMap} should be used to lookup the conditions using the
- * {@link #getChannelConstants(SvtChannel)} method.
+ * This class contains all test run SVT conditions data by readout channel. 
+ * {@link TestRunSvtChannel} objects from the SVT channel map should be used to
+ * lookup the conditions using the {@link #getChannelConstants(TestRunSvtChannel)}
+ * method.
  * 
  * @author Jeremy McCormick <[log in to unmask]>
  * @author Omar Moreno <[log in to unmask]>
  */
 public class TestRunSvtConditions extends AbstractSvtConditions {
 
-    protected TestRunSvtDaqMappingCollection daqMap = null;
-    
 	/**
      * Get the {@link TestRunSvtDaqMappingCollection} associated with these conditions.
      * 
@@ -25,33 +26,29 @@
      */
     @Override
     public TestRunSvtDaqMappingCollection getDaqMap() {
-        return daqMap;
+        return (TestRunSvtDaqMappingCollection) daqMap;
     }
 
+    /**
+     * Get the {@link TestRunSvtChannelCollection} for this set of conditions.
+     * 
+     * @return The SVT channel map.
+     */
     @Override
     public TestRunSvtChannelCollection getChannelMap() {
         return (TestRunSvtChannelCollection) channelMap;
     }
 
     /**
      * Set the {@link TestRunSvtDaqMappingCollection} associated with these conditions.
      * 
-     * @param daqMap The SVT DAQ map.
-	 * @return 
+     * @return The {@link TestRunSvtT0ShiftCollection}
      */
-    public void setDaqMap(TestRunSvtDaqMappingCollection daqMap) {
-        this.daqMap = daqMap;
+    @Override
+    public TestRunSvtT0ShiftCollection getT0Shifts() { 
+    	return (TestRunSvtT0ShiftCollection) t0Shifts;
     }
     
-    /**
-     * Set the channel map of type {@link TestRunSvtChannelCollection}.
-     * 
-     *  @param channelMap The SVT channel map.
-     */
-    public void setChannelMap(TestRunSvtChannelCollection channelMap){
-    	this.channelMap = channelMap;
-    }
-
     /**
      * Convert this object to a human readable string. This method prints a formatted
      * table of channel data independently of how its member objects implement their
@@ -25,33 +26,29 @@
 
     /**
-     * Set the {@link TestRunSvtDaqMappingCollection} associated with these conditions.
+     * Get the {@link TestRunSvtT0ShiftCollection} associated with these conditions.
      * 